@@ -1,15 +1,21 @@
+{-# LANGUAGE CPP #-}
+
+#if (__GLASGOW_HASKELL__ >= 802)
+{-# LANGUAGE DerivingStrategies #-}
+#endif
+
 --------------------------------------------------------------------------------
 --  See end of this file for licence information.
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Proof
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2016 Douglas Burke
+--                 2011, 2016, 2022 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  H98
+--  Portability :  CPP, DerivingStrategies
 --
 --  This module defines a framework for constructing proofs
 --  over some expression form.  It is intended to be used
@@ -47,7 +53,11 @@ data Step ex = Step
     { stepRule :: Rule ex           -- ^ Inference rule used
     , stepAnt  :: [Formula ex]      -- ^ Antecedents of inference rule
     , stepCon  :: Formula ex        -- ^ Named consequence of inference rule
-    } deriving Show
+    } deriving
+#if (__GLASGOW_HASKELL__ >= 802)
+    stock
+#endif
+    Show
 
 -- |Proof is a structure that presents a chain of rule applications
 --  that yield a result expression from a given expression
@@ -168,7 +178,7 @@ explainProof1 _     prev []       res   =
 explainProof1 rules prev (st:steps) res =
     case explainStep rules prev st  of
         Nothing -> explainProof1 rules (formExpr (stepCon st):prev) steps res
-        Just ex -> Just ("Invalid step: "++show (formName $ stepCon st)++": "++ex)
+        Just ex -> Just ("Invalid step: " ++ show (formName $ stepCon st) ++ ": " ++ ex)
 
 -- | A proof step is valid if rule is in list of rules
 --  and the antecedents are sufficient to obtain the conclusion
@@ -198,7 +208,7 @@ explainStep rules prev step =
         errors = catMaybes
             -- Rule name is one of supplied rules, and
             [ require (ruleName srul `elem` map ruleName rules)
-                      ("rule "++show (ruleName srul)++" not present")
+                      ("rule " ++ show (ruleName srul) ++ " not present")
             -- Antecedent expressions are all previously accepted expressions
             , require (S.fromList sant `S.isSubsetOf` S.fromList prev) -- (sant `subset` prev)
                       "antecedent not axiom or previous result"
@@ -258,7 +268,7 @@ showsSteps newline (s:ss) = showsStep  newline s .
 showsStep :: (ShowLines ex) => String -> Step ex -> ShowS
 showsStep newline s = showsFormula newline (stepCon s) .
                       showString newline .
-                      showString ("  (by ["++rulename++"] from "++antnames++")")
+                      showString ("  (by [" ++ rulename ++ "] from " ++ antnames ++ ")")
     where
         rulename = show . ruleName $ stepRule s
         antnames = showNames $ map (show . formName) (stepAnt s)
@@ -272,11 +282,11 @@ showNames (n1:ns) = showName n1 ++ ", " ++ showNames ns
 
 -- |Return a string representing a single name.
 showName :: String -> String
-showName n = "["++n++"]"
+showName n = "[" ++ n ++ "]"
 
 --------------------------------------------------------------------------------
 --
---  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011 Douglas Burke
+--  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2016, 2022 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
