@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  N3
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014, 2018, 2020 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -985,7 +985,7 @@ statementtail ::=		|	 "."  statementlist
 restoreState :: N3State -> N3Parser N3State
 restoreState origState = do
   oldState <- stGet
-  stUpdate $ \_ -> origState { nodeGen = nodeGen oldState }
+  stUpdate $ const origState { nodeGen = nodeGen oldState }
   return oldState
 
 {-
@@ -1232,7 +1232,7 @@ universal =
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013, 2014, 2018 Douglas Burke
+--    2011, 2012, 2013, 2014, 2018, 2020 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
